Купить Цифровое пианино Kawai ES100W в интернет-магазине МУЗДОМ по доступной цене. Описание, характеристики, отзывы.
Description: Цифровое пианино. Описание: клавиатура: 88 взвешенных клавиш; материал клавиш: пластик; механизм: Advanced Hammer Action IV-F (AHA IV-F); фортепианные тембры: концертный рояль, кабинетный рояль, сладкое пианино, сладкое пианино 2, современно...
Keywords: Цифровое пианино Kawai ES100W , цена, купить, заказать, интернет-магазин, отзывы, характеристики, МУЗДОМ

- Недавно просмотренные
- Избранные товары

В истории просмотров
вы можете найти недавно просмотренные товары

Мы сохраняем последние 20 товаров

В избранных товарах
вы можете найти все товары, добавленные в избранное

Здесь показано несколько последних

Список избранных товаров доступен зарегистрированным пользователям.
/

Доставка по России

бесплатно

Заказ товаров по телефону

+7 (495) 504-37-01

Оплатить
заказ

﻿Корзина0

- Оркестровые
  - Аккордеоны и баяны
    - Акустические
    - Кейсы и чехлы
    - Цифровые
  - Аксессуары Оркестровые
    - Пъезодатчики для струнных
    - Пюпитры
    - Сурдины
  - Кейсы, чехлы оркестровые
  - Процессоры эффектов для духовых
  - Сайлент-системы
  - Метрономы
  - Оркестровые ударные
    - Маршевые барабаны
    - Оркестровые барабаны
    - Тарелки
  - Деревянные духовые
    - Гобои
    - Кларнеты
    - Саксофоны
    - Фаготы
    - Флейты
    - Флейты-пикколо
  - Медные духовые
    - Трубы-пикколо
    - Альты и тенора
    - Баритоны (эфониумы)
    - Валторны
    - Корнеты
    - Маршевые духовые
    - Сузафоны
    - Тромбоны
    - Трубы
    - Тубы
    - Флюгельгорны
  - Смычковые инструменты
    - Альты струнные
    - Виолончели
    - Контрабасы
    - Скрипки
  - Оркестровая перкуссия
    - Колокольчики
    - Литавры
    - Глокеншпили
    - Виброфоны
    - Ксилофоны
    - Маримбы
  - Электроинструменты
    - Электровиолончели
    - Электроконтрабасы
    - Электроскрипки
- Гитары
  - Midi гитары
  - Электрогитары
    - 6-струнные
    - 7-струнные
    - 8-струнные
    - Именные
    - Леворукие
    - Баритон
    - Полуакустические
  - Акустические гитары
    - Сайлент-гитары
    - Резонаторные / добро
    - Трэвел-гитары
    - Классические гитары
    - Акустические
    - Электроакустические гитары
    - Классические со звукоснимателем
    - Классические гитары 1/2, 3/4, 7/8
    - 12-струнные гитары
    - Левосторонние
  - Бас-гитары
    - Именные бас-гитары
    - 4-струнные
    - 5-струнные
    - 6 и 8-струнные
    - Акустические
    - Безладовые
    - Леворукие
  - Педали эффектов
    - Шумоподавители
    - Тюнеры в форме педали
    - Аттеньюаторы
    - Acoustic
    - Bass
    - Chorus, Flanger
    - Компрессор/лимитер педали
    - Delay, Reverb
    - Дисторшн, овердрайв
    - Envelope, Synth
    - Селекторы, маршрутизаторы
    - Octaver, Phase Shifter, Pitch Shifter
    - Лупер-педали
    - TALK BOXES
    - Тремоло-педали
    - WAH
    - Громкости, экспрессии
    - Остальные
    - Педалборды
    - Роутеры/Селекторы
    - Эквалайзеры
    - Reverb
    - Fuzz
  - Гитарные процессоры, Midi
    - Для акустики
    - Midi контроллеры
    - MIDI-синтезаторы и датчики
    - Для бас-гитары
    - Для электрогитары
  - Гитарное усиление
    - Автономные комбо
    - Моделирующие усилители для наушников
    - Кабинеты басовые
    - Усилители для бас-гитар
    - Преампы, реампы, дибоксы
    - Кабинеты гитарные
    - Комбо для акустических гитар
    - Комбо для бас-гитар
    - Комбо для электрогитар
    - Стэки и комплекты
    - Усилители для электрогитар
  - Традиционные инструменты
    - Банджо
    - Мандолины
    - Укулеле
  - Аксессуары
    - Блоки питания
    - Гитарные ремни
    - Для усилителей
    - Патч-кабели
    - Сопутствующие товары
    - Подставки под ногу гитариста
    - Стулья для гитаристов
    - Переключатели для комбо и педалей
    - Звукосниматели
    - Стойки под гитарные комбо
    - Гитарные стойки
    - Пъезодатчики
    - Гитарные тюнеры
    - Гитарные чехлы и кейсы
- Ударные
  - Тренировочные пэды
  - Электронные ударные установки
  - Акустические ударные
    - Малые барабаны
    - Установки без стоек
    - Установки со стойками
  - Электронные ударные
    - Электронные барабанные модули
    - Рамы и крепления
    - Триггеры и пэды
    - Усилители
    - Цифровая перкуссия
  - Драм-машины и грув-боксы
    - Грув-боксы и сэмплеры
    - Драм-машины
  - Педали для бас-барабана
    - Двойные (карданы)
    - Одиночные
  - Тарелки
    - Rude
    - Гонги
    - China
    - Crash
    - Crash-Ride
    - Hi Hat
    - Ride
    - Splash
    - Комплекты тарелок
    - Спец. эффекты
  - Стойки и стулья
    - Держатели для тарелок
    - Стойки для гонга
    - Наборы стоек
    - Стойки журавль
    - Стойки для Hi Hat
    - Стойки для малого барабана
    - Стойки для томов
    - Стойки прямые
    - Стулья
  - Перкуссия
    - Бонго (Bongo)
    - Джембе (Djembes)
    - Ковбеллы (Cowbells)
    - Конго (Congo)
    - Чаймс (Chimes)
    - Шейкеры (Shakers)
  - Аксессуары
    - Наборы пластиков
    - Пластики на бас-барабан
    - Клэмпы и крепления
    - Пластики на малый барабан
    - Метрономы
    - Обслуживание и уход
    - Рамы
    - Чехлы для ударных
- Клавишные
  - Цифровые пианино
  - Синтезаторы и рабочие станции
    - Профессиональные синтезаторы
    - Рабочие станции
    - Синтезаторы для электронной музыки
  - Синтезаторы с автоаккомпанементом
    - Домашние синтезаторы
    - Профессиональные арранжировщики
  - Органы
  - Цифровые рояли
  - MIDI-клавиатуры и контроллеры
  - Клавишные комбо-усилители
  - Звуковые модули
  - Рояли и пианино
    - Сайлент-пианино
    - Акустические рояли
    - Акустические пианино
    - Дисклавиры
  - Аксессуары
    - Банкетки и стулья
    - Виртуальные инструменты и плагины
    - Педали для клавишных
    - Стойки для клавишных
    - Чехлы для клавишных
- Микрофоны
  - Микрофоны
    - Измерительные
    - Ламповые
    - Ленточные
    - USB-микрофоны
    - Вокальные ручные микрофоны
    - Конференсные микрофоны
    - Подобранные пары микрофонов
    - Головные
    - Инсталляционные
    - Инструментальные
    - Микрофоны-пушки
    - Микрофонные наборы
    - Граничного слоя
    - Накамерные и репортёрские
    - Петличные
    - Подвесные микрофоны
    - Стерео-микрофоны
    - Студийные с малой диафрагмой
    - Конструктор-микрофоны
    - Студийные с большой диафрагмой
  - Компоненты для радиосистем
    - Антенные сплиттеры
    - Кабель для поясных передатчиков
    - Приёмники
    - Антенны и аксессуары
  - Конференционные системы
    - Аксессуары
    - Микшеры
    - Пульты делегатов и компоненты
    - CS3
    - CS5
    - Конференц-микрофоны
    - Конференционные модульные
  - Радиосистемы
    - Сменные капсюли
    - Передатчики для радиосистем
    - Вокальные ручные радиосистемы
    - Головные радиосистемы
    - Петличные радиосистемы
    - Инструментальные радиосистемы
    - Двойные комплекты радиосистем
    - Накамерные (автономные) радиосистемы
    - Микрофоны для радиосистем
    - Цифровые автоматические микшеры
  - Персональный мониторинг
    - Бюджетные системы мониторинга
    - Компоненты
    - Радиосистемы мониторинга
    - Радиомониторы
  - Микрофонные стойки, аксессуары
    - Аксессуары для микрофонных стоек
    - Настольные микрофонные стойки
    - Гусиные шеи
    - Микрофонные стойки Журавль
    - Держатели для планшетов на стойки
    - Прямые микрофонные стойки
    - Микрофонные стойки-пантографы
    - Низкие микрофонные стойки
  - Аксессуары для микрофонов
    - USB-адаптеры
    - Адаптеры фантомного питания
    - Держатели, подвесы микрофонов
    - Ветрозащита для микрофонов
    - Крепления для микрофонов на инструменты
    - Поп-фильтры, экраны
    - Переходники с разъёмов микрофонов
- DJ
  - DJ аксессуары
    - Картриджы, иглы
    - Кейсы, стойки для диджеев
    - Коммутация для диджеев
    - Крышки для проигрывателей
    - Фонокорректоры
  - DJ проигрыватели CD/USB/SD
    - Наборы
    - Настольные
    - Рэковые
  - Проигрыватели виниловых дисков
  - DJ микшеры
  - DJ контроллеры и интерфейсы
    - C джогом
    - Без джога
  - DJ процессоры эффектов
- Студия
  - Генераторы синхросигнала
  - Звуковые карты
    - USB 3.0
    - MIDI-интерфейсы
    - USB
    - FireWire
    - PCI/PCIe
    - Карты расширения
    - Аксессуары для карт
    - Конвертеры
    - Коммутация
    - Thunderbolt
  - Студийные усилители
  - Студийные мониторы
    - 3-х полосные и более
    - Комплекты мониторов
    - Мониторы
    - Контроллеры управления
    - Сабвуферы
    - Стойки для мониторов
    - Компоненты для мониторов
  - Панели управления и контроллеры
  - Рекордеры и портастудии
    - Аксессуары
    - Многоканальные (портастудии)
    - Наладонные (диктофоны)
    - Микрофоны для рекордеров
    - Видеорекордеры
  - Программное обеспечение
    - Программные комплексы
  - Интерфейсы для Apple
    - iOS Звукозапись
    - Аксессуары
  - Акссессуары
    - Студийные патчбэи
    - Мебель для студии
  - Видео-оборудование
    - Видео-конвертеры
    - Видео-микшеры
- Звук
  - Прокат и аренда звукового оборудования
  - Акустические системы
    - Для кинотеатров
    - Колонны
    - Активные колонки
    - Пассивные
    - Мобильные комплекты
    - Линейные массивы
    - Комбо-системы
    - Сценические мониторы
    - Автономные с аккумулятором
    - d&b audiotechnik
  - Сабвуферы
    - Активные сабвуферы
    - Пассивные сабвуферы
  - Усилители мощности
    - 2-х канальные
    - 4-х канальные
    - 8-канальные
  - Микшерные пульты
    - Аналоговые микшеры
    - Цифровые микшеры
    - Микшеры-усилители (активные)
    - Аксессуары для микшеров
    - Инсталляционные
    - Радиовещательные микшеры
  - Приборы обработки звука
    - Подавители обратной связи
    - Подавители шумов
    - Спикер-процессоры, контроллеры АС
    - Свитчеры
    - Кроссоверы аналоговые и цифровые
    - DI-боксы
    - Сплиттеры
    - Сумматоры
    - AD/DA конвертеры
    - Вокальные процессоры
    - Зонные и матричные процессоры
    - Компрессоры, лимитеры, гейт
    - Динамические процессоры
    - Микрофонные предусилители
    - Процессоры эффектов
    - Психоакустические приборы
    - Графические эквалайзеры
  - Караоке
  - Трансляционное оборудование (PA)
    - Настенные панели управления
    - Всепогодная акустика
    - Зонные усилители, микшеры
    - Настенная акустика
    - Потолочные громкоговорители
    - Трансляционные контроллеры и модули
    - Звуковые прожекторы
    - Рупоры
    - Мегафоны ручные
  - Рэковые стойки, кейсы, ящики, шкафы
    - Рэковые кейсы
    - Рэковые панели
    - Аксессуары
    - Кейсы, чехлы
    - Рэковые стойки и шкафы
    - Рэковые полки
    - Рэковые ящики
  - Проигрыватели и рекордеры
  - Цифровые рекордеры
  - Наушники
    - Закрытого типа
    - Полуоткрытого типа
    - Открытого типа
    - Наушники-вставки мониторинговые
    - Гарнитурные
    - Для барабанщиков
    - Конференсные наушники
    - Беспроводные наушники
    - Аксессуары для наушников
    - Усилители-распределители
  - MIDAS
    - Аналоговые микшерные пульты
    - Стейджбоксы
    - Транспортировочные кейсы
    - Цифровые микшерные пульты Midas
  - Аксессуары
    - Измерительное оборудование
    - Сумки и кейсы для микшеров
    - Крепления для АС
    - Стаканы для колонок
    - Транспортировочные кейсы
    - Шумоизоляция
    - Подсветка
    - Роутеры и сплиттеры
    - Стойки для ноутбука
    - Стойки для акустических систем
    - Чехлы для акустических систем
- Свет
  - Архитектурные прожекторы
  - Генераторы эффектов
    - Генераторы CO2
    - Генераторы огня
    - Генераторы конфетти
    - Аксессуары для эффектов
    - Генераторы снега и пены
    - Ветродуи
    - Генераторы тумана
    - Дым-машины
    - Генераторы мыльных пузырей
    - Расходные материалы для спецэффектов
  - Диммеры
  - Зеркальные шары
  - Комплекты светового оборудования
  - Контровая заливка
  - Лазерное оборудование
    - Аксессуары для лазеров
    - Лазеры
    - Программы управления лазерами
  - Прожекторы полного движения (голова)
  - Светодиодные панели
  - Прожекторы следящего света
  - Прожекторы PAR LED
  - Пульты и контроллеры
    - Дистрибьютеры DMX сигнала
    - DMX радио передатчики
    - Конвертеры DMX сигнала
    - Сплиттеры, тестеры DMX
    - Программы управления
    - Пульты, контроллеры DMX
    - Световые процессоры
  - Световые эффекты
  - Сканеры
  - Стробоскопы
  - Театральные прожекторы
  - Ультрафиолет
  - Аксессуары для световых приборов
    - Держатели световых приборов
    - Лебёдки
    - Стойки для светового оборудования
    - Элеваторы
  - Комплекты светового оборудования
- - Коммутация
    - DI-Box и интерфейсы
    - Распределительные коробки
    - Кабель в бухтах
    - Разъёмы, переходники
    - Коммутационные, патч панели
    - Сетевые фильтры и дистрибьютеры
    - Шнуры, мультикоры

Производители по алфавиту: A B C D E F G H I J K L M N O P Q R S T U V W X Y Z Все

# Цифровое пианино Kawai ES100W

Музыкальные инструменты Kawai
Артикул: GMES100W

## Цифровое пианино Kawai ES100W

Цифровое пианино. Описание: клавиатура: 88 взвешенных клавиш; материал клавиш: пластик; механизм: Advanced Hammer Action IV-F (AHA IV-F); фортепианные тембры: концертный рояль, кабинетный рояль, сладкое пианино, сладкое пианино 2, современно...
Kawai ES100W Kawai ES100W Kawai ES100W

47 405Р
В корзину Купить в один клик В кредит за 47 405РТинькофф Банк
Есть в наличии – осталось 6 шт. Доставим сегодня с 18:00 до 23:00 или завтра днём при заказе до 12:00
Бесплатная доставка Условия

# Условия доставки

Мы всегда готовы обсудить любые варианты доставки, удобные для вас. Ниже описаны стандартные.

## ДОСТАВКА ПО МОСКВЕ

350 рублей в пределах МКАД.

## САМОВЫВОЗ

Бесплатно. Адрес пункта самовывоза: Москва, Ярославская д.10 корпус 4.

## ДОСТАВКА ПО МОСКОВСКОЙ ОБЛАСТИ

Тарифы в зависимости от расстояния от МКАД:
до 15 км: 750р. / до 30 км: 1000р. / до 50 км: 1500р. / до 100 км: 2000р.

## ДОСТАВКА ПО РОССИИ

Бесплатная доставка: осуществляется при сумме заказа от 25000 рублей (список городов доставки)

Платная доставка: стоимость обговаривается при подтверждении заказа (минимум 350 рублей)

Доставку можно осуществить при помощи компаний:
ЖелДорЭкспедиция, Деловые линии, ПЭК, а также для мелких посылок и труднодоступных мест используем EMS Почта России.

Сроки доставки по городам уточняйте у менеджеров.

## УСЛОВИЯ ДОСТАВКИ

Заказ оформляется в интернет-магазине или по телефону, по электронной почте высылается счет на оплату, который можно оплатить в любом банке по своему усмотрению. Также доступна оплата пластиковой картой и электронными способами такими, как Яндекс деньги и Вебмани.
После поступления денег на наш расчетный счет товар отправляется выбранной транспортной компанией.

## ДОСТАВКА В КАЗАХСТАН

Осуществляется ежедневно компаниями Желдорэкспедиция и Деловые линии. Стоимость от 700 руб.

## CПИСОК ГОРОДОВ С БЕСПЛАТНОЙ ДОСТАВКОЙ ПО РОССИИ

Музыкальный магазин Муздом в сотрудничестве с ведущей транспортной компанией ЖелДорЭкспедиция предлагает вам бесплатную железнодорожную доставку ваших товаров стоимостью свыше 25,000 рублей по многим городам России.

## Список "бесплатных" городов:

Абакан, Альметьевск, Армавир, Архангельск, Астрахань, Ачинск, Балаково, Барнаул, Белгород, Белогорск, Березники, Бийск, Биробиджан, Благовещенск, Братск, Брянск, Великий Новгород, Владимир, Волгоград, Волжский, Вологда, Воронеж, Глазов, Екатеринбург, Иваново, Ижевск, Иркутск, Йошкар-Ола, Казань, Калуга, Кемерово, Киров, Комсомольск-на-Амуре, Кострома, Краснодар, Красноярск, Курган, Курск, Липецк, Магнитогорск, Махачкала, Миасс, Мурманск, Набережные Челны, Нижневартовск, Нижний Новгород, Нижний Тагил, Новокузнецк, Новороссийск, Новосибирск, Новый Уренгой, Омск, Оренбург, Орел, Орск, Пенза, Пермь, Петрозаводск, Псков, Пятигорск, Ростов-на-Дону, Рубцовск, Рязань, Самара, Санкт-Петербург, Саранск, Саратов, Северодвинск, Смоленск, Сочи, Ставрополь, Стерлитамак, Сургут, Сыктывкар, Таганрог, Тамбов, Тверь, Тольятти, Томск, Тула, Тюмень, Улан-Удэ, Ульяновск, Усть-Илимск, Уфа, Чайковский, Чебоксары, Челябинск, Череповец, Чита, Ярославль.

## Хабаровск, Якутск, Петропавловск-Камчатский:

от 700 рублей

Крупногабаритные грузы объёмом свыше 0,2 куб.м. и (или) грузы весом свыше 25 кг: тарифы рассчитываются индивидуально согласно расценкам транспортной компании.

добавить в список желаний
Поделиться в Facebook Рассказать ВКонтакте Твитнуть в Twitter Отправить в Google +
Описание Характеристики Видео2 Отзывы и комментарии Может понравиться

## Описание Kawai ES100W

Цифровое пианино.
Описание:
клавиатура: 88 взвешенных клавиш;
материал клавиш: пластик;
механизм: Advanced Hammer Action IV-F (AHA IV-F);
фортепианные тембры: концертный рояль, кабинетный рояль, сладкое пианино, сладкое пианино 2, современное пианино, рок-пианино;
другие тембры: классическое электропиано, электропиано 60-х, современное электропиано, джазовый орган, церковный орган, медленная скрипка, скрипичный ансамбль, бас-гитара, электро-бас, клавесин, вибрафон;
источник тембров: система Harmonic Imaging с сэмплированием каждой из 88 клавиш;
полифония: 192 голоса;
реверберация: 3 типа – комната, сцена, концертный зал;
другие функции: перестановка, настройка, темперамент, выключение динамиков, память, заводские установки, автоматическое отключение питания;
двухслойный режим (DUAL): Есть (настраиваемый баланс звука);
игра в 4 руки: да;
выбор чувствительности клавиатуры: да;
функция обучения: основы игры на пианино от Alfred 1A/1B; 25 уроков Бургмюллера (Опус 100);
демонстрационные произведения: 12 песен;
метроном: 1/4, 2/4, 3/4, 4/4, 5/4, 3/8, 6/8 (Регулировка темпа и громкости), 100 барабанных ритмов;
записывающее устройство: 3 песни, 1 дорожка, максимум 15 000 нот;
разъемы: MIDI-Jack (IN/OUT), 2 выхода для наушников, разъём для педали;
звуковая система: 8x12 см x 2;
выходная мощность: 7 Вт x 2;
комплект поставки: педаль F-10H, сетевой адаптер PS-129, пюпитр;
потребляемая мощность: 9 Вт;
габариты (Д х Ш х В): 1312x286x145;
вес: 15 кг.

## Характеристики Kawai ES100W

- Артикул: GMES100W
- Бренд: Kawai

## Видео Kawai ES100W

## Отзывы и комментарии32

Оставляйте отзывы и комментарии, а появятся вопросы – пишите, мы ответим вам в самое ближайшее время.

Отзывы ВКонтакте Отзывы Facebook | Muzdom

Купить в 1 клик
Ваше имя *
Обязательно укажите ваше имя
Контактный телефон *
Обязательно укажите контактный телефон
В номере телефона допускаются только цифры, скобки, пробелы, знак плюса и тире
E-mail *
Укажите правильный e-mail или оставьте поле пустым
Укажите правильный e-mail или оставьте поле пустым
Спасибо за заказ!
Ошибка!
В ближайшее время наш менеджер свяжется с вами.

## Выберите способ оплаты

Укажите номер заказа который
назвал вам оператор при
оформлении заказа

#### Товар добавлен к сравнению

Продолжить покупки

#### Товар добавлен в корзину

Продолжить покупки Заказать

#### Вы подписались на товар

Продолжить покупки

Мы оповестим вас о поступлении товара по указанному email

Ваш email

Авторизация

Войти на сайт

Вы можете войти на сайт, если вы зарегистрированы на одном из этих сервисов:
Facebook
Twitter
ВКонтакте
Одноклассники
Яндекс OpenID
Mail.Ru
Используйте вашу учетную запись на Facebook.com для входа на сайт.
Используйте вашу учетную запись на Twitter.com для входа на сайт.
Используйте вашу учетную запись VKontakte для входа на сайт.
Используйте вашу учетную запись Odnoklassniki.ru для входа на сайт.
@yandex.ru
@mail.ru

Логин
Пароль

Запомнить меня Забыли пароль
Отмена Назад Подписаться
Войти на сайт

#### Через социальные сети

Вы можете войти на сайт, если вы зарегистрированы на одном из этих сервисов:
Facebook
Twitter
ВКонтакте
Одноклассники
Яндекс OpenID
Mail.Ru
Используйте вашу учетную запись на Facebook.com для входа на сайт.
Используйте вашу учетную запись на Twitter.com для входа на сайт.
Используйте вашу учетную запись VKontakte для входа на сайт.
Используйте вашу учетную запись Odnoklassniki.ru для входа на сайт.
@yandex.ru
@mail.ru

#### Обычная авторизация

Запомнить меня

Забыли пароль

Поддержка пользователей: +7 (495) 504 37 01